@@ -2,8 +2,9 @@
 from .mahalanobis import geochemical_filter
 from .KDE import KDE, MD, iqr_one_peak
 from .formula_recalc import recalc
+from .formula_recalc import recalc_Fe
+
 
-# Optional: expose package version (no hardcoding)
 try:
     from importlib.metadata import version as _v
 except ImportError:  # Python <3.8 backport, but you require >=3.8 so this is mostly moot
